==> task-api-java-0.3.0-sources.jar: java/edu/iu/dsc/tws/api/compute/executor/ExecutorContext.java <==
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
package edu.iu.dsc.tws.api.compute.executor;

import edu.iu.dsc.tws.api.config.Config;
import edu.iu.dsc.tws.api.config.Context;

public class ExecutorContext extends Context {

  public static final String THREADS_PER_WORKER = "twister2.exector.worker.threads";
  public static final String INSTANCE_QUEUE_LOW_WATERMARK =
      "twister2.exector.instance.queue.low.watermark";
  public static final String INSTANCE_QUEUE_HIGH_WATERMARK =
      "twister2.exector.instance.queue.high.watermark";
  public static final String BATCH_EXECUTOR = "twister2.executor.batch.name";
  public static final String BATCH_EXECUTOR_SHARING_SEP_COMM
      = "edu.iu.dsc.tws.executor.threading.BatchSharingExecutor";
  public static final String BATCH_EXECUTOR_SHARING
      = "edu.iu.dsc.tws.executor.threading.BatchSharingExecutor2";

  public static final String TWISTER2_RUNTIME_OBJECT = "_twister2.runtime_";

  public static int threadsPerContainer(Config cfg) {
    return cfg.getIntegerValue(THREADS_PER_WORKER, 1);
  }

  public static int instanceQueueLowWaterMark(Config cfg) {
    return cfg.getIntegerValue(INSTANCE_QUEUE_LOW_WATERMARK, 64);
  }

  public static int instanceQueueHighWaterMark(Config cfg) {
    return cfg.getIntegerValue(INSTANCE_QUEUE_HIGH_WATERMARK, 128);
  }

  public static String getBatchExecutor(Config cfg) {
    return cfg.getStringValue(BATCH_EXECUTOR, BATCH_EXECUTOR_SHARING_SEP_COMM);
  }
}

==> task-api-java-0.8.0-sources.jar: java/edu/iu/dsc/tws/api/compute/executor/ExecutorContext.java <==
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
package edu.iu.dsc.tws.api.compute.executor;

import edu.iu.dsc.tws.api.config.Config;
import edu.iu.dsc.tws.api.config.Context;

public class ExecutorContext extends Context {

  public static final String THREADS_PER_WORKER = "twister2.exector.worker.threads";
  public static final String INSTANCE_QUEUE_LOW_WATERMARK =
      "twister2.exector.instance.queue.low.watermark";
  public static final String INSTANCE_QUEUE_HIGH_WATERMARK =
      "twister2.exector.instance.queue.high.watermark";
  public static final String BATCH_EXECUTOR = "twister2.executor.batch.name";
  public static final String STREAM_EXECUTOR = "twister2.executor.stream.name";
  public static final String BATCH_EXECUTOR_SHARING_SEP_COMM
      = "edu.iu.dsc.tws.executor.threading.BatchSharingExecutor";
  public static final String BATCH_EXECUTOR_SHARING
      = "edu.iu.dsc.tws.executor.threading.BatchSharingExecutor2";

  public static final String STREAM_EXECUTOR_ALL_SHARING =
      "edu.iu.dsc.tws.executor.threading.StreamingAllSharingExecutor";
  public static final String STREAM_EXECUTOR_DEDICATED_COMM =
      "edu.iu.dsc.tws.executor.threading.StreamingSharingExecutor";


  public static final String TWISTER2_RUNTIME_OBJECT = "_twister2.runtime_";

  public static int threadsPerContainer(Config cfg) {
    return cfg.getIntegerValue(THREADS_PER_WORKER, 1);
  }

  public static int instanceQueueLowWaterMark(Config cfg) {
    return cfg.getIntegerValue(INSTANCE_QUEUE_LOW_WATERMARK, 64);
  }

  public static int instanceQueueHighWaterMark(Config cfg) {
    return cfg.getIntegerValue(INSTANCE_QUEUE_HIGH_WATERMARK, 128);
  }

  public static String getBatchExecutor(Config cfg) {
    return cfg.getStringValue(BATCH_EXECUTOR, BATCH_EXECUTOR_SHARING);
  }

  public static String getStreamExecutor(Config cfg) {
    return cfg.getStringValue(STREAM_EXECUTOR, STREAM_EXECUTOR_DEDICATED_COMM);
  }
}
